Changelog
=========


(unreleased)
------------
- Added GenericGather and associated test. [Andreas Wicenec]
- Updated fmt. [Andreas Wicenec]
- Added check and test for wrong output drop name. [Andreas Wicenec]


v0.1.5 (2021-12-22)
-------------------
- Release: version v0.1.5 🚀 [Andreas Wicenec]
- Fixed linting errors. [Andreas Wicenec]
- Added AdvUrlRetrieve component and tests. [Andreas Wicenec]
- Fixed linting errors. [Andreas Wicenec]
- Added ExtractColumn component. [Andreas Wicenec]
- Typo in doxygen. [Andreas Wicenec]
- Fixed appclass doxygen strings. [Andreas Wicenec]
- Ignore long line in doxygen for lint. [Andreas Wicenec]
- Fixed requirements-test and requirements. [Andreas Wicenec]
- Adjusted test. [Andreas Wicenec]
- Another merge attempt. [Andreas Wicenec]
- Release: version v0.1.1 🚀 [Andreas Wicenec]
- Djusted test_cmpts. [Andreas Wicenec]
- Increased test coverage to 100% [Andreas Wicenec]
- Release: version v0.2.1 🚀 [Andreas Wicenec]
- Added FileGlob and PickOne components with tests. [Andreas Wicenec]
- Debugging of environment variables. [james-strauss-uwa]
- Debugging of environment variables. [james-strauss-uwa]
- Added palette action. [Andreas Wicenec]
- Added .vscode to gitigonre. [Andreas Wicenec]
- Removed pandas from requirements. [Andreas Wicenec]
- Data component type change. [Andreas Wicenec]
- Removed main. [Andreas Wicenec]
- Reverted Pandas changes. [Andreas Wicenec]


v0.1.4 (2021-12-16)
-------------------
- Release: version v0.1.4 🚀 [Andreas Wicenec]


v0.1.3 (2021-12-16)
-------------------
- Release: version v0.1.3 🚀 [Andreas Wicenec]
- Release: version v0.1.3 🚀 [Andreas Wicenec]
- Fixed case where data was written as a string, not pickled. [Andreas
  Wicenec]
- Release: version v0.1.3 🚀 [Andreas Wicenec]


v0.1.2 (2021-12-16)
-------------------
- Release: version v0.1.2 🚀 [Andreas Wicenec]
- Fixed lint complaint. [Andreas Wicenec]
- Added String2JSON app. [Andreas Wicenec]


v0.1.1 (2021-12-16)
-------------------
- Release: version v0.1.1 🚀 [Andreas Wicenec]


v0.1.0 (2021-12-13)
-------------------
- Release: version v0.1.0 🚀 [Andreas Wicenec]
- Release: version v0.1.0 🚀 [Andreas Wicenec]
- Updated README and init. [Andreas Wicenec]
- Renamed apps and data. [Andreas Wicenec]
- Updated readme. [Andreas Wicenec]
- Removed last mentioning of full name. [Andreas Wicenec]
- Release: version v0.2.3 🚀 [Andreas Wicenec]
- Fixed setup script. [Andreas Wicenec]
- Release: version v0.2.3 🚀 [Andreas Wicenec]
- Refactoring names. [Andreas Wicenec]
- Refactoring names. [Andreas Wicenec]
- Release: version v0.2.2 🚀 [Andreas Wicenec]
- Release: version v0.2.4 🚀 [Andreas Wicenec]
- Release: version v0.2.4 🚀 [Andreas Wicenec]
- Update requirements.txt. [awicenec]

  more dashes
- Update requirements-test.txt. [awicenec]

  the dashes cause issues
- Release: version v0.2.3 🚀 [Andreas Wicenec]
- Release: version v0.2.2 🚀 [Andreas Wicenec]
- Increased test coverage to 100% [Andreas Wicenec]
- Release: version v0.2.1 🚀 [Andreas Wicenec]
- Better testing for array type. [Andreas Wicenec]
- Release: version v0.2.0 🚀 [Andreas Wicenec]
- Added FileGlob and PickOne components with tests. [Andreas Wicenec]
- Better installation description. [Andreas Wicenec]
- Fixed linting errors. [Andreas Wicenec]
- Release: version v0.1.9 🚀 [Andreas Wicenec]
- Removed translator from requirements. [Andreas Wicenec]
- Release: version v0.1.8 🚀 [Andreas Wicenec]
- Release: version v0.1.7 🚀 [Andreas Wicenec]
- Added gitchangelog config; commented testpypi upload. [Andreas
  Wicenec]
- Fix the sequence for PyPi upload. [Andreas Wicenec]
- Release: version v0.1.6 🚀 [Andreas Wicenec]
- Release: version v0.1.5 🚀 [Andreas Wicenec]
- Fixed workflow. [Andreas Wicenec]
- Added creation of dist package for test_pypi. [Andreas Wicenec]
- Added test_pypi to standard commits. [Andreas Wicenec]
- Removed repository again. [Andreas Wicenec]
- Release: version v0.1.4 🚀 [Andreas Wicenec]
- Release: version v0.1.3 🚀 [Andreas Wicenec]
- Still no luck with PyPi. [Andreas Wicenec]
- Release: version v0.1.3 🚀 [Andreas Wicenec]
- Added 'v' to release tag. [Andreas Wicenec]
- Release: version 0.1.3 🚀 [Andreas Wicenec]
- PyPi upload does not work with repository flag, try without. [Andreas
  Wicenec]
- Fixed fmt. [Andreas Wicenec]
- Added automatic PiPi upload. [Andreas Wicenec]
- Update test code coverage. [Andreas Wicenec]
- README updates. [Andreas Wicenec]
- Another update to requirements.txt. [Andreas Wicenec]
- Updated requirements.txt. [Andreas Wicenec]
- Added daliuge to test requirements. [Andreas Wicenec]
- Removed template stuff and Windows support. [Andreas Wicenec]
- Merge. [Andreas Wicenec]
- Removed template stuff and Windows support. [Andreas Wicenec]
- Removed template stuff and Windows support. [Andreas Wicenec]
- Update LICENSE. [awicenec]
- Linting and blackening. [Andreas Wicenec]
- Initial commit of branchApp. [Andreas Wicenec]
- ✅ Ready to clone and code. [awicenec]
- Initial commit. [awicenec]


